@@ -57,3 +57,19 @@ class Sfw:
         """
 
         return get_api("sfw/neko")["link"]
+
+    @staticmethod
+    def highfive():
+        """
+        A Function That Will Return a SFW Highfive GIF
+        """
+        
+        return get_api("sfw/highfive")["link"]
+    
+    @staticmethod
+    def slap():
+        """
+        A Function That Will Return a SFW Slap GIF
+        """
+        
+        return get_api("sfw/slap")["link"]
\ No newline at end of file
